@@ -14,5 +14,6 @@ from .core import (NotificationMsg,
                    broadcast_alert,
                    broadcast_warning,
                    broadcast_error,
-                   broadcast_critical)
+                   broadcast_critical,
+                   priority_of)
 from robotnikmq.log import log
