@@ -15,6 +15,28 @@ class Priority(IntEnum):
     CRITICAL = 4
 
 
+INFO = {'info', 'information', 'i'}
+ACTIVITY = {'activity', 'a'}
+WARNING = {'warning', 'warn', 'w'}
+ERROR = {'error', 'err', 'e'}
+CRITICAL = {'critical', 'crit', 'c'}
+
+
+@typechecked
+def priority_of(candidate: str) -> Priority:
+    if candidate.lower() in INFO:
+        return Priority.INFO
+    if candidate.lower() in ACTIVITY:
+        return Priority.ACTIVITY
+    if candidate.lower() in WARNING:
+        return Priority.WARNING
+    if candidate.lower() in ERROR:
+        return Priority.ERROR
+    if candidate.lower() in CRITICAL:
+        return Priority.CRITICAL
+    raise ValueError(f'"{candidate}" cannot be mapped to a valid priority')
+
+
 class NotificationMsg:
     @typechecked
     def __init__(self,
